==> react-date-primitives-0.4.3.tgz: package/esnext/utils.js <==
const monthsCache = new Map();
export function setDay(date, day) {
    const newDate = new Date(date.getTime());
    newDate.setDate(day);
    return newDate;
}
export function addDays(date, days) {
    return setDay(date, date.getDate() + days);
}
export function setMonth(date, month) {
    const newDate = new Date(date.getTime());
    newDate.setMonth(month);
    return newDate;
}
export function addMonths(date, months) {
    return setMonth(date, date.getMonth() + months);
}
export function setYear(date, year) {
    const newDate = new Date(date.getTime());
    newDate.setFullYear(year);
    return newDate;
}
export function startOfMonth(date) {
    const newDate = new Date(date.getTime());
    newDate.setDate(1);
    newDate.setHours(0, 0, 0, 0);
    return newDate;
}
export function endOfMonth(date) {
    const newDate = new Date(date.getTime());
    newDate.setFullYear(date.getFullYear(), date.getMonth() + 1, 0);
    newDate.setHours(23, 59, 59, 999);
    return newDate;
}
export function isSameMonth(dateLeft, dateRight) {
    return (dateLeft.getFullYear() === dateRight.getFullYear() &&
        dateLeft.getMonth() === dateRight.getMonth());
}
export function isSameDay(dateLeft, dateRight) {
    return (dateLeft.getFullYear() === dateRight.getFullYear() &&
        dateLeft.getMonth() === dateRight.getMonth() &&
        dateLeft.getDate() === dateRight.getDate());
}
export function isDayAfter(date, dateToCompare) {
    const newDate = new Date(date.getTime());
    const newDateToCompare = new Date(dateToCompare.getTime());
    newDate.setHours(0, 0, 0, 0);
    newDateToCompare.setHours(0, 0, 0, 0);
    return newDate.getTime() > newDateToCompare.getTime();
}
export function isDayBefore(date, dateToCompare) {
    const newDate = new Date(date.getTime());
    const newDateToCompare = new Date(dateToCompare.getTime());
    newDate.setHours(0, 0, 0, 0);
    newDateToCompare.setHours(0, 0, 0, 0);
    return newDate.getTime() < newDateToCompare.getTime();
}
export function callIfExists(callback, ...args) {
    if (typeof callback === 'function') {
        callback(...args);
    }
}
export function getDatesofMonth(month) {
    const firstDate = startOfMonth(month);
    const key = `${firstDate.getFullYear()}-${firstDate.getMonth()}`;
    const data = monthsCache.get(key);
    if (data) {
        return data;
    }
    /*
        Logic to see how many weeks we will have to render, this can be easily done by :
        Math.ceil of ((Get the first day in current month + total number of days in month) / (No. of days in week i.e. 7))
    */
    const firstDayInCurrentMonth = firstDate.getDay();
    const lastDate = endOfMonth(month);
    const noOfWeeks = Math.ceil((firstDayInCurrentMonth + lastDate.getDate()) / 7);
    const newdata = Array.from({ length: noOfWeeks }, (_1, i) => {
        const week = Array.from({ length: 7 }, (_2, j) => {
            const day = addDays(firstDate, i * 7 + j - firstDayInCurrentMonth);
            return { date: day, inCurrentMonth: isSameMonth(firstDate, day) };
        });
        return week;
    });
    monthsCache.set(key, newdata);
    return newdata;
}

==> react-date-primitives-0.7.0.tgz: package/esnext/utils.js <==
const monthsCache = new Map();
export function setDay(date, day) {
    const newDate = new Date(date.getTime());
    newDate.setDate(day);
    return newDate;
}
export function addDays(date, days) {
    return setDay(date, date.getDate() + days);
}
export function setMonth(date, month) {
    const newDate = new Date(date.getTime());
    newDate.setMonth(month);
    return newDate;
}
export function addMonths(date, months) {
    return setMonth(date, date.getMonth() + months);
}
export function setYear(date, year) {
    const newDate = new Date(date.getTime());
    newDate.setFullYear(year);
    return newDate;
}
export function startOfMonth(date) {
    const newDate = new Date(date.getTime());
    newDate.setDate(1);
    newDate.setHours(0, 0, 0, 0);
    return newDate;
}
export function endOfMonth(date) {
    const newDate = new Date(date.getTime());
    newDate.setFullYear(date.getFullYear(), date.getMonth() + 1, 0);
    newDate.setHours(23, 59, 59, 999);
    return newDate;
}
export function isSameMonth(dateLeft, dateRight) {
    return (dateLeft.getFullYear() === dateRight.getFullYear() &&
        dateLeft.getMonth() === dateRight.getMonth());
}
export function isSameDay(dateLeft, dateRight) {
    return (dateLeft.getFullYear() === dateRight.getFullYear() &&
        dateLeft.getMonth() === dateRight.getMonth() &&
        dateLeft.getDate() === dateRight.getDate());
}
export function isDayAfter(date, dateToCompare) {
    const newDate = new Date(date.getTime());
    const newDateToCompare = new Date(dateToCompare.getTime());
    newDate.setHours(0, 0, 0, 0);
    newDateToCompare.setHours(0, 0, 0, 0);
    return newDate.getTime() > newDateToCompare.getTime();
}
export function isDayBefore(date, dateToCompare) {
    const newDate = new Date(date.getTime());
    const newDateToCompare = new Date(dateToCompare.getTime());
    newDate.setHours(0, 0, 0, 0);
    newDateToCompare.setHours(0, 0, 0, 0);
    return newDate.getTime() < newDateToCompare.getTime();
}
export function callIfExists(callback, ...args) {
    if (typeof callback === 'function') {
        callback(...args);
    }
}
export function getDaysOfMonth(month) {
    const firstDate = startOfMonth(month);
    const key = `${firstDate.getFullYear()}-${firstDate.getMonth()}`;
    const data = monthsCache.get(key);
    if (data) {
        return data;
    }
    const firstDayInCurrentMonth = firstDate.getDay();
    const newdata = Array.from({ length: 6 }, (_1, i) => {
        const week = Array.from({ length: 7 }, (_2, j) => {
            const day = addDays(firstDate, i * 7 + j - firstDayInCurrentMonth);
            return { date: day, inCurrentMonth: isSameMonth(firstDate, day) };
        });
        return week;
    });
    monthsCache.set(key, newdata);
    return newdata;
}
